@@ -855,8 +855,7 @@ stan_eta_transform <- function(family, llh_adj = FALSE) {
   stopifnot(all(c("family", "link") %in% names(family)))
   link <- family$link
   !(!is_skewed(family) && link == "identity" ||
-    is_ordinal(family) || is_categorical(family) ||
-    is_zero_inflated(family) || is_hurdle(family)) &&
+    is_ordinal(family) || is_categorical(family)) &&
   (llh_adj || !stan_has_built_in_fun(family))
 }
 
@@ -879,14 +878,19 @@ stan_eta_ilink <- function(family, auxpars = NULL,
     )
     nu <- paste0("nu", mix)
     nu <- ifelse(nu %in% auxpars, paste0(nu, "[n]"), nu)
-    fl <- ifelse(family %in% c("gamma", "exponential"), 
-                 paste0(family, "_", link), family)
+    fl <- ifelse(
+      family %in% c("gamma", "hurdle_gamma", "exponential"), 
+      paste0(family, "_", link), family
+    )
     ilink <- stan_ilink(link)
     out <- switch(fl,
       c(paste0(ilink, "("), ")"),
       gamma_log = c(paste0(shape, " * exp(-("), "))"),
       gamma_inverse = c(paste0(shape, " * ("), ")"),
       gamma_identity = c(paste0(shape, " / ("), ")"),
+      hurdle_gamma_log = c(paste0(shape, " * exp(-("), "))"),
+      hurdle_gamma_inverse = c(paste0(shape, " * ("), ")"),
+      hurdle_gamma_identity = c(paste0(shape, " / ("), ")"),
       exponential_log = c("exp(-(", "))"),
       exponential_inverse = c("(", ")"),
       exponential_identity = c("inv(", ")"),
@@ -940,6 +944,14 @@ stan_auxpar_defs <- function(auxpar) {
       "  real<lower=0,upper=1> ", 
       ";  // hurdle probability \n"
     ),
+    zoi = c(
+      "  real<lower=0,upper=1> ", 
+      ";  // zero-one-inflation probability \n"
+    ), 
+    coi = c(
+      "  real<lower=0,upper=1> ", 
+      ";  // conditional one-inflation probability \n"
+    ),
     bs = c(
       "  real<lower=0> ", 
       ";  // boundary separation parameter \n"
