@@ -23,8 +23,7 @@ test_that("plotting functions don't throw unexpected errors", {
   expect_error(stanplot(fit, type = "density"), "Invalid plot type")
   
   # pairs.brmsfit
-  # uncomment as soon as bayesplot 1.2.0 is on CRAN
-  # expect_s3_class(pairs(fit, pars = parnames(fit)[1:3]), "bayesplot_grid")
+  expect_s3_class(pairs(fit, pars = parnames(fit)[1:3]), "bayesplot_grid")
   
   # marginal_effects: manual checks of plotting method
   N <- 90
